# Generated by Django 5.2.7 on 2025-10-14 00:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_he", "0012_historicaleducationtype"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="singleton_field",
            field=models.CharField(
                default="",
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                unique=True,
                verbose_name="subject identifier",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="singleton_field",
            field=models.CharField(
                default="",
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                unique=True,
                verbose_name="subject identifier",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="singleton_field",
            field=models.CharField(
                default="",
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                unique=True,
                verbose_name="subject identifier",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="singleton_field",
            field=models.CharField(
                default="",
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                unique=True,
                verbose_name="subject identifier",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="singleton_field",
            field=models.CharField(
                default="",
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                unique=True,
                verbose_name="subject identifier",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                verbose_name="subject identifier",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                verbose_name="subject identifier",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                verbose_name="subject identifier",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                verbose_name="subject identifier",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                verbose_name="subject identifier",
            ),
            preserve_default=False,
        ),
    ]
